package net.wanji.opt.cache;

import lombok.extern.slf4j.Slf4j;
import net.wanji.common.framework.Constants;
import net.wanji.common.utils.tool.StringUtils;
import net.wanji.databus.dao.entity.RidInfoEntity;
import net.wanji.databus.dao.mapper.RidInfoMapper;
import org.springframework.boot.CommandLineRunner;
import org.springframework.stereotype.Component;
import org.springframework.util.CollectionUtils;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.List;
import java.util.stream.Collectors;
import java.util.stream.Stream;

/**
 * @author duanruiming
 * @date 2023/03/07 13:44
 */
@Component
@Slf4j
public class CrossRidInfoCache implements CommandLineRunner {

    @Resource
    RidInfoMapper ridInfoMapper;

    private static List<RidInfoEntity> ridInfoList = new ArrayList<>();

    public List<RidInfoEntity> getRidInfoAllList() {
        return ridInfoList;
    }

    public List<RidInfoEntity> getRidInfoListByCrossId(String startCrossId, String endCrossId) {
        Stream<RidInfoEntity> stream = ridInfoList.stream();
        if (StringUtils.isNotBlank(startCrossId)) {
            stream = stream.filter(ridInfoEntity -> StringUtils.equalsIgnoreCase(startCrossId, ridInfoEntity.getStartCrossId()));
        }
        if (StringUtils.isNotBlank(endCrossId)) {
            stream = stream.filter(ridInfoEntity -> StringUtils.equalsIgnoreCase(endCrossId, ridInfoEntity.getEndCrossId()));
        }
        return stream.collect(Collectors.toList());
    }

    @Override
    public void run(String... args) throws Exception {
        init();
    }

    public void init() {
        List<RidInfoEntity> ridInfoEntities = ridInfoMapper.selectOne(Constants.SystemParam.NULL, Constants.SystemParam.NULL);
        if (!CollectionUtils.isEmpty(ridInfoEntities)) {
            ridInfoList.addAll(ridInfoEntities);
        }
    }
}
